/* Name: desc.c
 * Project: AVR USB driver for AT90USB
 * Author: Koji Suzuki
 * Creation Date: 2007-12-10
 * Tabsize: 8
 * Copyright: (c) 2006 by Recursion Co., Ltd.
 * Copyright: (c) 2007 by Koji Suzuki (suz@nmj2.sakura.ne.jp)
 * Original Project: AVR USB driver for CDC interface on Low-Speed USB
 * Original Author: Osamu Tamura
 * License: Proprietary, free under certain conditions. See Documentation.
 */

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/wdt.h>
#include <util/delay.h>

#include "usbconfig.h"
#include "desc.h"

/* -------------------------- Device Description --------------------------- */

#define USB_CFG_EXTERNAL_CONFIG_DESCRIPTOR_LENGH    (9+9)

/* Define this to the size of your configuration descriptor if you provide
 * your own configuration descriptor at the global program memory address
 * 'usbDescrConfig'.
 */

#define  USB_CFG_VENDOR_ID  0xc0, 0x16  /* 5824 in dec, stands for VOTI */
/* USB vendor ID for the device, low byte first. If you have registered your
 * own Vendor ID, define it here. Otherwise you use obdev's free shared
 * VID/PID pair. Be sure to read USBID-License.txt for rules!
 */
#define USB_CFG_DEVICE_ID   0xdc, 0x05  /* 1500 in dec, obdev's free PID */
/* This is the ID of the product, low byte first. It is interpreted in the
 * scope of the vendor ID. If you have registered your own VID with usb.org
 * or if you have licensed a PID from somebody else, define it here. Otherwise
 * you use obdev's free shared VID/PID pair. Be sure to read the rules in
 * USBID-License.txt!
 */
#define  USB_CFG_DEVICE_VERSION  0x02, 0x01

#define  USB_CFG_IS_SELF_POWERED 0

PROGMEM char usbDescrDevice[] = {    /* USB device descriptor */
    18,         /* sizeof(usbDescrDevice): length of descriptor */
    USB_DESCR_DEVICE,    /* descriptor type */
    0x01, 0x01, /* USB version supported */
    0,		/* device class */
    0,		/* subclass */
    0,          /* protocol */
    EP_SIZE,       /* max packet size */
    USB_CFG_VENDOR_ID,  /* 2 bytes */
    USB_CFG_DEVICE_ID,  /* 2 bytes */
    USB_CFG_DEVICE_VERSION, /* 2 bytes */
    1,          /* manufacturer string index */
    2,          /* product string index */
    0,          /* serial number string index */
    1,          /* number of configurations */
};

PROGMEM char usbDescrConfig[] = {    /* USB configuration descriptor */
    9,          /* sizeof(usbDescrConfig): length of descriptor */
    USB_DESCR_CONFIG,    /* descriptor type */
    USB_CFG_EXTERNAL_CONFIG_DESCRIPTOR_LENGH,
    0,          /* total length of data returned (including inlined descriptors) */
    1,          /* number of interfaces in this configuration */
    1,          /* index of this configuration */
    0,          /* configuration name string index */
#if USB_CFG_IS_SELF_POWERED
    USB_ATTR_SELFPOWER,  /* attributes */
#else
    USB_ATTR_BUSPOWER,   /* attributes */
#endif
    100/2,            /* max USB current in 2mA units */

    /* interface descriptor : */
    9,          /* sizeof(usbDescrInterface): length of descriptor */
    USB_DESCR_INTERFACE, /* descriptor type */
    2,          /* index of this interface */
    0,          /* alternate setting for this interface */
    0,   /* endpoints excl 0: number of endpoint descriptors to follow */
    0xff, /* Class */
    0, /* subclass: */
    0, /* protocol */
    0,          /* string index for interface */
};

PROGMEM int16_t  usbDescrString0[] = {
	4 | (3<<8),	/* size, descriptor type */
	0x0409		/* language index (0x0409 = US-English) */
};

PROGMEM int16_t  usbDescrString1[] = {
    14*2 | (3<<8),
    'w', 'w', 'w', '.', 'f', 'i', 's', 'c', 'h', 'l', '.', 'd', 'e', 0
};

PROGMEM int16_t  usbDescrString2[] = {
    7*2 | (3<<8),
    'U', 'S', 'B', 'a', 's', 'p', 0
};

PROGMEM int16_t  usbDescrString3[] = {
	0 | (3<<8)
};

PROGMEM int16_t  *usbDescrStringTable[4] = {
	usbDescrString0,
	usbDescrString1,
	usbDescrString2,
	usbDescrString3 
};
